package claim_monitor

import (
	"fmt"
	"io"
	"net/http"

	"github.com/tidwall/gjson"
)

type Client struct {
	Server string
}

func NewClient(server string) *Client {
	return &Client{
		Server: server,
	}
}

func (cli *Client) GetClaimedAmount(address string) (string, error) {
	resp, err := http.DefaultClient.Get(fmt.Sprintf("%s/api/v1/claimed?address=%s", cli.Server, address))
	if err != nil {
		return "0", err
	}
	defer resp.Body.Close()
	data, err := io.ReadAll(resp.Body)
	if err != nil {
		return "0", err
	}

	if gjson.Get(string(data), "code").Int() != 0 {
		return "0", fmt.Errorf(string(data))
	}

	return gjson.Get(string(data), "data.claimed").String(), nil
}

func (cli *Client) GetClaimRecord(address string, page, pageSize int) ([]byte, error) {
	resp, err := http.DefaultClient.Get(fmt.Sprintf("%s/api/v1/record?address=%s&page=%d&pageSize=%d", cli.Server, address, page, pageSize))
	if err != nil {
		return nil, err
	}
	defer resp.Body.Close()
	return io.ReadAll(resp.Body)
}
